{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% block modal-body-right %}
<h3>{% trans "Description:" %}</h3>
<p>{% trans "Modify name, recovery_method and description of a failover segment." %}</p>
{% endblock %}
