{% extends 'base.html' %}
{% load i18n %}

{% block css %}
  {% include "_stylesheets.html" %}
  <link href='{{ STATIC_URL }}masakaridashboard/css/style.css' type='text/css' media='screen' rel='stylesheet' />
{% endblock %}
